#setwd("C:/mine/blog/bloggers/Id")
# A program written by Nick Stokes www.moyhu.blogspot.com, to emulate a 5x5 recon from
#A Reconstruction of Regional and Global Temperature for the Past 11,300 Years
# Shaun A. Marcott,  Jeremy D. Shakun,  Peter U. Clark,    and Alan C. Mix
#Science 8 March 2013: 339 (6124), 1198-1201. [DOI:10.1126/science.1228026] 
#http://www.sciencemag.org/content/339/6124/1198.abstract

# Need this package:
  getxls=F  # set to T if you need to read the XL file directly
 if(getxls) library("xlsReadWrite")
 # The spreadsheet is at this URL "http://www.sciencemag.org/content/suppl/2013/03/07/339.6124.1198.DC1/Marcott.SM.database.S1.xlsx"
 # Unfortunately it can't be downloaded and used directly because the R package can't read the format. You need to open it in Excel or OpenOffice and save in an older format.
 
	loc="Marcott.SM.database.S1.xls"
  prox=list()
  # Read the lat/lon data
    if(getxls){
      lat=read.xls(loc,sheet=2,from=2,naStrings="NaN",colClasses="numeric")[2:77,5:6]
      }  else load("prox.sav") # If the XL file has already been read
    o=is.na(lat[,1])
    lat=as.matrix(lat[!o,])
    w=rep(0,36*72)
    wu=1:73; k=1;
    for(i in 1:73){
      j=lat[i,]%/%5;
      j=j[1]+j[2]*36+1297;
      if(w[j]==0){w[j]=k;k=k+1;}
      wu[i]=w[j];
    }
  # Read and linearly interpolate data in 20 yr intervals (from 1940)
  m=11300/20
  tm=1:m*20-10
  g=list()
  h=NULL
  if(getxls){
  for(i in 1:73){	
    prox[[i]]=read.xls(loc,sheet=i+4,from=2,naStrings="NaN",colClasses="numeric")[,5:6]
    }
  save(prox,lat,file="prox.sav")
  }
  
  for(i in 1:73){	
    u=prox[[i]]
    g[[i]]=approx(u[[1]],u[[2]],xout=tm) # R's linear int
    y=g[[i]]$y
    y=y-mean(y[-10:10+300]) # anomaly to 5800-6200 BR
    h=cbind(h,y)
  }
  r=NULL  #  Will be the recon
  # now the tricky 5x5 weighting - different for each time step
  for(i in 1:nrow(h)){
  o=!is.na(h[i,])  # marks the data this year
  g=h[i,o]; 
  u=wu[o]; n=match(u,u); a=table(n); d=as.numeric(names(a));
  e=u;e[d]=a;wt=1/e[n]; #wt=weights
  r=c(r,sum(g*wt)/sum(wt))
  }
  # Now standardize to 1961-90, but via using M et al value = -0.04 at 1950 BP
  r=r-r[98]-0.04
  # now tricky graphics. my.png is the recon. ma.png is cut from fig 1b of the paper. You have to cut it exactly as shown to get the alignment right
  png("myrecon.png",width=450,height=370)
  par(bg="#ffffff00")  # The transparent background
  par(mar=c(6,5,3,0.5))
  plot(tm,r,type="l",xlim=c(11300,0),ylim=c(-1.2,0.8),col="#ff4400",lwd=3,yaxp=c(-1.2,0.8,5))
  dev.off()
  # Now an ImageMagick command to superpose the pngs
  # You can skip this if you don't have IM (but you should)
  system("composite myrecon.png ma.png recons.png")
